# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/msp/identities.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/msp/identities.proto',
  package='msp',
  syntax='proto3',
  serialized_options=_b('\n!org.hyperledger.fabric.protos.mspZ(github.com/hyperledger/fabric/protos/msp'),
  serialized_pb=_b('\n\x1fhfc/protos/msp/identities.proto\x12\x03msp\"5\n\x12SerializedIdentity\x12\r\n\x05mspid\x18\x01 \x01(\t\x12\x10\n\x08id_bytes\x18\x02 \x01(\x0c\"a\n\x18SerializedIdemixIdentity\x12\r\n\x05nym_x\x18\x01 \x01(\x0c\x12\r\n\x05nym_y\x18\x02 \x01(\x0c\x12\n\n\x02ou\x18\x03 \x01(\x0c\x12\x0c\n\x04role\x18\x04 \x01(\x0c\x12\r\n\x05proof\x18\x05 \x01(\x0c\x42M\n!org.hyperledger.fabric.protos.mspZ(github.com/hyperledger/fabric/protos/mspb\x06proto3')
)




_SERIALIZEDIDENTITY = _descriptor.Descriptor(
  name='SerializedIdentity',
  full_name='msp.SerializedIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mspid', full_name='msp.SerializedIdentity.mspid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_bytes', full_name='msp.SerializedIdentity.id_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=93,
)


_SERIALIZEDIDEMIXIDENTITY = _descriptor.Descriptor(
  name='SerializedIdemixIdentity',
  full_name='msp.SerializedIdemixIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nym_x', full_name='msp.SerializedIdemixIdentity.nym_x', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nym_y', full_name='msp.SerializedIdemixIdentity.nym_y', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ou', full_name='msp.SerializedIdemixIdentity.ou', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='msp.SerializedIdemixIdentity.role', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proof', full_name='msp.SerializedIdemixIdentity.proof', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=192,
)

DESCRIPTOR.message_types_by_name['SerializedIdentity'] = _SERIALIZEDIDENTITY
DESCRIPTOR.message_types_by_name['SerializedIdemixIdentity'] = _SERIALIZEDIDEMIXIDENTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SerializedIdentity = _reflection.GeneratedProtocolMessageType('SerializedIdentity', (_message.Message,), dict(
  DESCRIPTOR = _SERIALIZEDIDENTITY,
  __module__ = 'hfc.protos.msp.identities_pb2'
  # @@protoc_insertion_point(class_scope:msp.SerializedIdentity)
  ))
_sym_db.RegisterMessage(SerializedIdentity)

SerializedIdemixIdentity = _reflection.GeneratedProtocolMessageType('SerializedIdemixIdentity', (_message.Message,), dict(
  DESCRIPTOR = _SERIALIZEDIDEMIXIDENTITY,
  __module__ = 'hfc.protos.msp.identities_pb2'
  # @@protoc_insertion_point(class_scope:msp.SerializedIdemixIdentity)
  ))
_sym_db.RegisterMessage(SerializedIdemixIdentity)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 281165273@qq.com. All Rights Reserved.
#
# SPDX-License-Identifier: Apache-2.0

CC_INSTALL = "install"
CC_INSTANTIATE = "deploy"
CC_INVOKE = "invoke"
CC_UPGRADE = "upgrade"
CC_QUERY = "query"

CC_TYPE_GOLANG = "GOLANG"
CC_TYPE_JAVA = "JAVA"
CC_TYPE_NODE = "NODE"
CC_TYPE_CAR = "CAR"


class TXProposalRequest(object):
    """Class represents transaction proposal request."""

    def __init__(self, prop_type=None, cc_path=None,
                 cc_type=CC_TYPE_GOLANG, cc_name=None,
                 cc_version=None, fcn=None, args=None,
                 cc_endorsement_policy=None,
                 transient_map=None, packaged_cc=None,
                 collections_config=None):
        """ Construct transaction proposal request

        :param cc_type: chaincode type
        :param prop_type: proposal type
        :param packaged_cc: chaincode gz.tar bytes
        :param transient_map: transient data map
        :param cc_endorsement_policy: chaincode endorsement policy
        :param args: function arguments
        :param fcn: function name
        :param cc_version: chaincode version
        :param cc_name: chaincode name
        :param cc_path: chaincode path
        :param collections_config: collection config
        :return: An instance of TXProposalRequest or None

        """
        self._cc_type = cc_type
        self._prop_type = prop_type
        self._cc_path = cc_path
        self._cc_name = cc_name
        self._cc_version = cc_version
        self._fcn = fcn
        if args is None:
            self._args = []
        else:
            self._args = args
        self._packaged_cc = packaged_cc
        self._cc_endorsement_policy = cc_endorsement_policy
        self._collections_config = collections_config
        if transient_map is None:
            self._transient_map = []
        else:
            self._transient_map = transient_map

    @property
    def cc_type(self):
        """Get chaincode type

        :return: return chaincode type

        """
        return self._cc_type

    @cc_type.setter
    def cc_type(self, cc_type):
        """Set chaincode type

        :param cc_type: chaincode type

        """
        self._cc_type = cc_type

    @property
    def prop_type(self):
        """Get proposal type

        :return: return proposal type

        """
        return self._prop_type

    @prop_type.setter
    def prop_type(self, prop_type):
        """Set proposal type

        :param prop_type: proposal type
        :return:

        """
        self._prop_type = prop_type

    @property
    def cc_path(self):
        """Get chaincode path

        :return: return chaincode path

        """
        return self._cc_path

    @cc_path.setter
    def cc_path(self, cc_path):
        """Set chaincode path

        :param cc_path: chaincode path
        :return:

        """
        self._cc_path = cc_path

    @property
    def cc_name(self):
        """Get chaincode name

        :return: return chaincode name

        """
        return self._cc_name

    @cc_name.setter
    def cc_name(self, cc_name):
        """Set chaincode name

        :param cc_name: chaincode name
        :return:

        """
        self._cc_name = cc_name

    @property
    def cc_version(self):
        """Get chaincode version

        :return: return chaincode version

        """
        return self._cc_version

    @cc_version.setter
    def cc_version(self, cc_version):
        """Set chaincode version

        :param cc_version: chaincode version
        :return:

        """
        self._cc_version = cc_version

    @property
    def fcn(self):
        """Get function name

        :return: return function name

        """
        return self._fcn

    @fcn.setter
    def fcn(self, fcn):
        """Set function name

        :param fcn: function name
        :return:

        """
        self._fcn = fcn

    @property
    def args(self):
        """Get function arguments

        :return: return function arguments

        """
        return self._args

    @args.setter
    def args(self, args):
        """Set function arguments

        :param args: function arguments
        :return:

        """
        self._args = args

    @property
    def packaged_cc(self):
        """Get packaged chaincode

        :return: return packaged chaincode

        """
        return self._packaged_cc

    @packaged_cc.setter
    def packaged_cc(self, packaged_cc):
        """Set packaged chaincode

        :param packaged_cc: packaged chaincode
        :return:

        """
        self._packaged_cc = packaged_cc

    @property
    def cc_endorsement_policy(self):
        """Get endorsement policy

        :return: return endorsement policy

        """
        return self._cc_endorsement_policy

    @cc_endorsement_policy.setter
    def cc_endorsement_policy(self, cc_endorsement_policy):
        """Set endorsement policy

        :param cc_endorsement_policy: endorsement policy
        :return:

        """
        self._cc_endorsement_policy = cc_endorsement_policy

    @property
    def transient_map(self):
        """Get transient map

        :return: return transient map

        """
        return self._transient_map

    @transient_map.setter
    def transient_map(self, transient_map):
        """Set transient map

        :param transient_map: transient map
        :return:

        """
        self._transient_map = transient_map

    @property
    def collections_config(self):
        """Get collections config

        :return: return collections config

        """
        return self._collections_config

    @collections_config.setter
    def collections_config(self, collections_config):
        """Set collections config

        :param collections_config: collections config
        :return:

        """
        self._collections_config = collections_config


def validate(tx_prop_req):
    """Check transaction proposal request.

    :param tx_prop_req: see TXProposalRequest
    :return: transaction proposal request if no error
    :raises ValueError: Invalid transaction proposal request

    """
    if not tx_prop_req:
        raise ValueError("Missing proposal request object")

    if not tx_prop_req.cc_name:
        raise ValueError("Missing 'cc_name' parameter "
                         "in the proposal request")

    if tx_prop_req.prop_type == CC_INSTALL:
        if not tx_prop_req.cc_path:
            raise ValueError("Missing 'cc_path' parameter "
                             "in the proposal request")

    if not tx_prop_req.cc_version and tx_prop_req.prop_type not in (CC_QUERY,
                                                                    CC_INVOKE):
        raise ValueError("Missing 'cc_version' parameter "
                         "in the proposal request")

    if tx_prop_req.prop_type != CC_INSTALL:
        if not tx_prop_req.fcn:
            raise ValueError("Missing 'fcn' parameter "
                             "in the proposal request")

    if tx_prop_req.prop_type == CC_INVOKE:
        if tx_prop_req.args is None and not tx_prop_req.transient_map:
            raise ValueError("Missing 'args' or 'transient_map'"
                             "parameter in the proposal request")
    return tx_prop_req


def create_tx_prop_req(prop_type=None, cc_path=None, cc_type=CC_TYPE_GOLANG,
                       cc_name=None, cc_version=None, fcn=None, args=None,
                       cc_endorsement_policy=None,
                       transient_map=None, packaged_cc=None,
                       collections_config=None):
    """Create a transaction proposal request

    :param prop_type: proposal request type (Default value = None)
    :param cc_path: chaincode path (Default value = None)
    :param cc_name: chaincode name (Default value = None)
    :param cc_version: chaincode version (Default value = None)
    :param fcn: function name (Default value = None)
    :param args: function arguments (Default value = None)
    :param cc_endorsement_policy: chaincode endorsement policy (Default value = None)
    :param transient_map: transient data map (Default value = None)
    :param packaged_cc: packaged chaincode source
    :param cc_type:  (Default value = CC_TYPE_GOLANG)
    :param collections_config:  (Default value = None)
    :return: a transaction proposal request (Default value = None)

    """
    tx_prop_req = TXProposalRequest(
        prop_type, cc_path, cc_type, cc_name, cc_version, fcn,
        args, cc_endorsement_policy, transient_map,
        packaged_cc, collections_config)
    return validate(tx_prop_req)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/peer/transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from hfc.protos.peer import proposal_response_pb2 as hfc_dot_protos_dot_peer_dot_proposal__response__pb2
from hfc.protos.common import common_pb2 as hfc_dot_protos_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/peer/transaction.proto',
  package='protos',
  syntax='proto3',
  serialized_options=_b('\n\"org.hyperledger.fabric.protos.peerB\022TransactionPackageZ)github.com/hyperledger/fabric/protos/peer'),
  serialized_pb=_b('\n!hfc/protos/peer/transaction.proto\x12\x06protos\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'hfc/protos/peer/proposal_response.proto\x1a\x1ehfc/protos/common/common.proto\"A\n\x11SignedTransaction\x12\x19\n\x11transaction_bytes\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"]\n\x14ProcessedTransaction\x12-\n\x13transactionEnvelope\x18\x01 \x01(\x0b\x32\x10.common.Envelope\x12\x16\n\x0evalidationCode\x18\x02 \x01(\x05\"9\n\x0bTransaction\x12*\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x19.protos.TransactionAction\"4\n\x11TransactionAction\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"m\n\x16\x43haincodeActionPayload\x12\"\n\x1a\x63haincode_proposal_payload\x18\x01 \x01(\x0c\x12/\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x1f.protos.ChaincodeEndorsedAction\"g\n\x17\x43haincodeEndorsedAction\x12!\n\x19proposal_response_payload\x18\x01 \x01(\x0c\x12)\n\x0c\x65ndorsements\x18\x02 \x03(\x0b\x32\x13.protos.Endorsement*\x94\x05\n\x10TxValidationCode\x12\t\n\x05VALID\x10\x00\x12\x10\n\x0cNIL_ENVELOPE\x10\x01\x12\x0f\n\x0b\x42\x41\x44_PAYLOAD\x10\x02\x12\x15\n\x11\x42\x41\x44_COMMON_HEADER\x10\x03\x12\x19\n\x15\x42\x41\x44_CREATOR_SIGNATURE\x10\x04\x12 \n\x1cINVALID_ENDORSER_TRANSACTION\x10\x05\x12\x1e\n\x1aINVALID_CONFIG_TRANSACTION\x10\x06\x12\x1a\n\x16UNSUPPORTED_TX_PAYLOAD\x10\x07\x12\x15\n\x11\x42\x41\x44_PROPOSAL_TXID\x10\x08\x12\x12\n\x0e\x44UPLICATE_TXID\x10\t\x12\x1e\n\x1a\x45NDORSEMENT_POLICY_FAILURE\x10\n\x12\x16\n\x12MVCC_READ_CONFLICT\x10\x0b\x12\x19\n\x15PHANTOM_READ_CONFLICT\x10\x0c\x12\x13\n\x0fUNKNOWN_TX_TYPE\x10\r\x12\x1a\n\x16TARGET_CHAIN_NOT_FOUND\x10\x0e\x12\x14\n\x10MARSHAL_TX_ERROR\x10\x0f\x12\x10\n\x0cNIL_TXACTION\x10\x10\x12\x15\n\x11\x45XPIRED_CHAINCODE\x10\x11\x12\x1e\n\x1a\x43HAINCODE_VERSION_CONFLICT\x10\x12\x12\x18\n\x14\x42\x41\x44_HEADER_EXTENSION\x10\x13\x12\x16\n\x12\x42\x41\x44_CHANNEL_HEADER\x10\x14\x12\x18\n\x14\x42\x41\x44_RESPONSE_PAYLOAD\x10\x15\x12\r\n\tBAD_RWSET\x10\x16\x12\x14\n\x10ILLEGAL_WRITESET\x10\x17\x12\x14\n\x10INVALID_WRITESET\x10\x18\x12\x12\n\rNOT_VALIDATED\x10\xfe\x01\x12\x19\n\x14INVALID_OTHER_REASON\x10\xff\x01*(\n\x0cMetaDataKeys\x12\x18\n\x14VALIDATION_PARAMETER\x10\x00\x42\x63\n\"org.hyperledger.fabric.protos.peerB\x12TransactionPackageZ)github.com/hyperledger/fabric/protos/peerb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,hfc_dot_protos_dot_peer_dot_proposal__response__pb2.DESCRIPTOR,hfc_dot_protos_dot_common_dot_common__pb2.DESCRIPTOR,])

_TXVALIDATIONCODE = _descriptor.EnumDescriptor(
  name='TxValidationCode',
  full_name='protos.TxValidationCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIL_ENVELOPE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_PAYLOAD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_COMMON_HEADER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_CREATOR_SIGNATURE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ENDORSER_TRANSACTION', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONFIG_TRANSACTION', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_TX_PAYLOAD', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_PROPOSAL_TXID', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_TXID', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENDORSEMENT_POLICY_FAILURE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MVCC_READ_CONFLICT', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHANTOM_READ_CONFLICT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TX_TYPE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_CHAIN_NOT_FOUND', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MARSHAL_TX_ERROR', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIL_TXACTION', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRED_CHAINCODE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHAINCODE_VERSION_CONFLICT', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_HEADER_EXTENSION', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_CHANNEL_HEADER', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_RESPONSE_PAYLOAD', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_RWSET', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_WRITESET', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_WRITESET', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_VALIDATED', index=25, number=254,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OTHER_REASON', index=26, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=643,
  serialized_end=1303,
)
_sym_db.RegisterEnumDescriptor(_TXVALIDATIONCODE)

TxValidationCode = enum_type_wrapper.EnumTypeWrapper(_TXVALIDATIONCODE)
_METADATAKEYS = _descriptor.EnumDescriptor(
  name='MetaDataKeys',
  full_name='protos.MetaDataKeys',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VALIDATION_PARAMETER', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1305,
  serialized_end=1345,
)
_sym_db.RegisterEnumDescriptor(_METADATAKEYS)

MetaDataKeys = enum_type_wrapper.EnumTypeWrapper(_METADATAKEYS)
VALID = 0
NIL_ENVELOPE = 1
BAD_PAYLOAD = 2
BAD_COMMON_HEADER = 3
BAD_CREATOR_SIGNATURE = 4
INVALID_ENDORSER_TRANSACTION = 5
INVALID_CONFIG_TRANSACTION = 6
UNSUPPORTED_TX_PAYLOAD = 7
BAD_PROPOSAL_TXID = 8
DUPLICATE_TXID = 9
ENDORSEMENT_POLICY_FAILURE = 10
MVCC_READ_CONFLICT = 11
PHANTOM_READ_CONFLICT = 12
UNKNOWN_TX_TYPE = 13
TARGET_CHAIN_NOT_FOUND = 14
MARSHAL_TX_ERROR = 15
NIL_TXACTION = 16
EXPIRED_CHAINCODE = 17
CHAINCODE_VERSION_CONFLICT = 18
BAD_HEADER_EXTENSION = 19
BAD_CHANNEL_HEADER = 20
BAD_RESPONSE_PAYLOAD = 21
BAD_RWSET = 22
ILLEGAL_WRITESET = 23
INVALID_WRITESET = 24
NOT_VALIDATED = 254
INVALID_OTHER_REASON = 255
VALIDATION_PARAMETER = 0



_SIGNEDTRANSACTION = _descriptor.Descriptor(
  name='SignedTransaction',
  full_name='protos.SignedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_bytes', full_name='protos.SignedTransaction.transaction_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='protos.SignedTransaction.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=216,
)


_PROCESSEDTRANSACTION = _descriptor.Descriptor(
  name='ProcessedTransaction',
  full_name='protos.ProcessedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionEnvelope', full_name='protos.ProcessedTransaction.transactionEnvelope', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validationCode', full_name='protos.ProcessedTransaction.validationCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=311,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='protos.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='protos.Transaction.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=370,
)


_TRANSACTIONACTION = _descriptor.Descriptor(
  name='TransactionAction',
  full_name='protos.TransactionAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='protos.TransactionAction.header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='protos.TransactionAction.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=424,
)


_CHAINCODEACTIONPAYLOAD = _descriptor.Descriptor(
  name='ChaincodeActionPayload',
  full_name='protos.ChaincodeActionPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chaincode_proposal_payload', full_name='protos.ChaincodeActionPayload.chaincode_proposal_payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='protos.ChaincodeActionPayload.action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=535,
)


_CHAINCODEENDORSEDACTION = _descriptor.Descriptor(
  name='ChaincodeEndorsedAction',
  full_name='protos.ChaincodeEndorsedAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_response_payload', full_name='protos.ChaincodeEndorsedAction.proposal_response_payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endorsements', full_name='protos.ChaincodeEndorsedAction.endorsements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=640,
)

_PROCESSEDTRANSACTION.fields_by_name['transactionEnvelope'].message_type = hfc_dot_protos_dot_common_dot_common__pb2._ENVELOPE
_TRANSACTION.fields_by_name['actions'].message_type = _TRANSACTIONACTION
_CHAINCODEACTIONPAYLOAD.fields_by_name['action'].message_type = _CHAINCODEENDORSEDACTION
_CHAINCODEENDORSEDACTION.fields_by_name['endorsements'].message_type = hfc_dot_protos_dot_peer_dot_proposal__response__pb2._ENDORSEMENT
DESCRIPTOR.message_types_by_name['SignedTransaction'] = _SIGNEDTRANSACTION
DESCRIPTOR.message_types_by_name['ProcessedTransaction'] = _PROCESSEDTRANSACTION
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['TransactionAction'] = _TRANSACTIONACTION
DESCRIPTOR.message_types_by_name['ChaincodeActionPayload'] = _CHAINCODEACTIONPAYLOAD
DESCRIPTOR.message_types_by_name['ChaincodeEndorsedAction'] = _CHAINCODEENDORSEDACTION
DESCRIPTOR.enum_types_by_name['TxValidationCode'] = _TXVALIDATIONCODE
DESCRIPTOR.enum_types_by_name['MetaDataKeys'] = _METADATAKEYS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignedTransaction = _reflection.GeneratedProtocolMessageType('SignedTransaction', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTRANSACTION,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.SignedTransaction)
  ))
_sym_db.RegisterMessage(SignedTransaction)

ProcessedTransaction = _reflection.GeneratedProtocolMessageType('ProcessedTransaction', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEDTRANSACTION,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProcessedTransaction)
  ))
_sym_db.RegisterMessage(ProcessedTransaction)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)

TransactionAction = _reflection.GeneratedProtocolMessageType('TransactionAction', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONACTION,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.TransactionAction)
  ))
_sym_db.RegisterMessage(TransactionAction)

ChaincodeActionPayload = _reflection.GeneratedProtocolMessageType('ChaincodeActionPayload', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEACTIONPAYLOAD,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeActionPayload)
  ))
_sym_db.RegisterMessage(ChaincodeActionPayload)

ChaincodeEndorsedAction = _reflection.GeneratedProtocolMessageType('ChaincodeEndorsedAction', (_message.Message,), dict(
  DESCRIPTOR = _CHAINCODEENDORSEDACTION,
  __module__ = 'hfc.protos.peer.transaction_pb2'
  # @@protoc_insertion_point(class_scope:protos.ChaincodeEndorsedAction)
  ))
_sym_db.RegisterMessage(ChaincodeEndorsedAction)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hfc/protos/common/policies.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hfc.protos.msp import msp_principal_pb2 as hfc_dot_protos_dot_msp_dot_msp__principal__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hfc/protos/common/policies.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/common'),
  serialized_pb=_b('\n hfc/protos/common/policies.proto\x12\x06\x63ommon\x1a\"hfc/protos/msp/msp_principal.proto\"k\n\x06Policy\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\"D\n\nPolicyType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSIGNATURE\x10\x01\x12\x07\n\x03MSP\x10\x02\x12\x11\n\rIMPLICIT_META\x10\x03\"{\n\x17SignaturePolicyEnvelope\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12%\n\x04rule\x18\x02 \x01(\x0b\x32\x17.common.SignaturePolicy\x12(\n\nidentities\x18\x03 \x03(\x0b\x32\x14.common.MSPPrincipal\"\x9f\x01\n\x0fSignaturePolicy\x12\x13\n\tsigned_by\x18\x01 \x01(\x05H\x00\x12\x32\n\x08n_out_of\x18\x02 \x01(\x0b\x32\x1e.common.SignaturePolicy.NOutOfH\x00\x1a;\n\x06NOutOf\x12\t\n\x01n\x18\x01 \x01(\x05\x12&\n\x05rules\x18\x02 \x03(\x0b\x32\x17.common.SignaturePolicyB\x06\n\x04Type\"\x7f\n\x12ImplicitMetaPolicy\x12\x12\n\nsub_policy\x18\x01 \x01(\t\x12-\n\x04rule\x18\x02 \x01(\x0e\x32\x1f.common.ImplicitMetaPolicy.Rule\"&\n\x04Rule\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0c\n\x08MAJORITY\x10\x02\x42S\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric/protos/commonb\x06proto3')
  ,
  dependencies=[hfc_dot_protos_dot_msp_dot_msp__principal__pb2.DESCRIPTOR,])



_POLICY_POLICYTYPE = _descriptor.EnumDescriptor(
  name='PolicyType',
  full_name='common.Policy.PolicyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNATURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPLICIT_META', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=119,
  serialized_end=187,
)
_sym_db.RegisterEnumDescriptor(_POLICY_POLICYTYPE)

_IMPLICITMETAPOLICY_RULE = _descriptor.EnumDescriptor(
  name='Rule',
  full_name='common.ImplicitMetaPolicy.Rule',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAJORITY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=565,
  serialized_end=603,
)
_sym_db.RegisterEnumDescriptor(_IMPLICITMETAPOLICY_RULE)


_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='common.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='common.Policy.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='common.Policy.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POLICY_POLICYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=187,
)


_SIGNATUREPOLICYENVELOPE = _descriptor.Descriptor(
  name='SignaturePolicyEnvelope',
  full_name='common.SignaturePolicyEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='common.SignaturePolicyEnvelope.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule', full_name='common.SignaturePolicyEnvelope.rule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identities', full_name='common.SignaturePolicyEnvelope.identities', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=312,
)


_SIGNATUREPOLICY_NOUTOF = _descriptor.Descriptor(
  name='NOutOf',
  full_name='common.SignaturePolicy.NOutOf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='n', full_name='common.SignaturePolicy.NOutOf.n', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='common.SignaturePolicy.NOutOf.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=466,
)

_SIGNATUREPOLICY = _descriptor.Descriptor(
  name='SignaturePolicy',
  full_name='common.SignaturePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_by', full_name='common.SignaturePolicy.signed_by', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='n_out_of', full_name='common.SignaturePolicy.n_out_of', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SIGNATUREPOLICY_NOUTOF, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Type', full_name='common.SignaturePolicy.Type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=315,
  serialized_end=474,
)


_IMPLICITMETAPOLICY = _descriptor.Descriptor(
  name='ImplicitMetaPolicy',
  full_name='common.ImplicitMetaPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub_policy', full_name='common.ImplicitMetaPolicy.sub_policy', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule', full_name='common.ImplicitMetaPolicy.rule', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMPLICITMETAPOLICY_RULE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=603,
)

_POLICY_POLICYTYPE.containing_type = _POLICY
_SIGNATUREPOLICYENVELOPE.fields_by_name['rule'].message_type = _SIGNATUREPOLICY
_SIGNATUREPOLICYENVELOPE.fields_by_name['identities'].message_type = hfc_dot_protos_dot_msp_dot_msp__principal__pb2._MSPPRINCIPAL
_SIGNATUREPOLICY_NOUTOF.fields_by_name['rules'].message_type = _SIGNATUREPOLICY
_SIGNATUREPOLICY_NOUTOF.containing_type = _SIGNATUREPOLICY
_SIGNATUREPOLICY.fields_by_name['n_out_of'].message_type = _SIGNATUREPOLICY_NOUTOF
_SIGNATUREPOLICY.oneofs_by_name['Type'].fields.append(
  _SIGNATUREPOLICY.fields_by_name['signed_by'])
_SIGNATUREPOLICY.fields_by_name['signed_by'].containing_oneof = _SIGNATUREPOLICY.oneofs_by_name['Type']
_SIGNATUREPOLICY.oneofs_by_name['Type'].fields.append(
  _SIGNATUREPOLICY.fields_by_name['n_out_of'])
_SIGNATUREPOLICY.fields_by_name['n_out_of'].containing_oneof = _SIGNATUREPOLICY.oneofs_by_name['Type']
_IMPLICITMETAPOLICY.fields_by_name['rule'].enum_type = _IMPLICITMETAPOLICY_RULE
_IMPLICITMETAPOLICY_RULE.containing_type = _IMPLICITMETAPOLICY
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
DESCRIPTOR.message_types_by_name['SignaturePolicyEnvelope'] = _SIGNATUREPOLICYENVELOPE
DESCRIPTOR.message_types_by_name['SignaturePolicy'] = _SIGNATUREPOLICY
DESCRIPTOR.message_types_by_name['ImplicitMetaPolicy'] = _IMPLICITMETAPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), dict(
  DESCRIPTOR = _POLICY,
  __module__ = 'hfc.protos.common.policies_pb2'
  # @@protoc_insertion_point(class_scope:common.Policy)
  ))
_sym_db.RegisterMessage(Policy)

SignaturePolicyEnvelope = _reflection.GeneratedProtocolMessageType('SignaturePolicyEnvelope', (_message.Message,), dict(
  DESCRIPTOR = _SIGNATUREPOLICYENVELOPE,
  __module__ = 'hfc.protos.common.policies_pb2'
  # @@protoc_insertion_point(class_scope:common.SignaturePolicyEnvelope)
  ))
_sym_db.RegisterMessage(SignaturePolicyEnvelope)

SignaturePolicy = _reflection.GeneratedProtocolMessageType('SignaturePolicy', (_message.Message,), dict(

  NOutOf = _reflection.GeneratedProtocolMessageType('NOutOf', (_message.Message,), dict(
    DESCRIPTOR = _SIGNATUREPOLICY_NOUTOF,
    __module__ = 'hfc.protos.common.policies_pb2'
    # @@protoc_insertion_point(class_scope:common.SignaturePolicy.NOutOf)
    ))
  ,
  DESCRIPTOR = _SIGNATUREPOLICY,
  __module__ = 'hfc.protos.common.policies_pb2'
  # @@protoc_insertion_point(class_scope:common.SignaturePolicy)
  ))
_sym_db.RegisterMessage(SignaturePolicy)
_sym_db.RegisterMessage(SignaturePolicy.NOutOf)

ImplicitMetaPolicy = _reflection.GeneratedProtocolMessageType('ImplicitMetaPolicy', (_message.Message,), dict(
  DESCRIPTOR = _IMPLICITMETAPOLICY,
  __module__ = 'hfc.protos.common.policies_pb2'
  # @@protoc_insertion_point(class_scope:common.ImplicitMetaPolicy)
  ))
_sym_db.RegisterMessage(ImplicitMetaPolicy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
